#!/bin/bash
#Automatically Created by buildpkg 1.3.3
#Maintainer: Johannes Marbach <jm@rapidrabbit.de>
#url: http://www.xm1math.net/pstplus/

######Begin Redundant Code######################################
check_for_root() {
	if [ "$UID" != "0" ]; then
		echo "You need to be root"
		exit 1
	fi
}

clean_dirs () {
        for COMPLETED in src pkg; do
                if [ -e $COMPLETED ]; then
                        rm -rf $COMPLETED
                fi
        done
}

clean_old_builds () {
	for COMPLETED in $package.{tgz,md5,dep}; do
		if [ -e $COMPLETED ]; then
			rm -rf $COMPLETED
		fi
	done
	clean_dirs
}

set_pre_permissions() {
	cd $startdir/src
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
}


check_for_menu_complaince() {
	if [ -d "$startdir/pkg/usr/share/applications" ]; then
		cd $startdir/pkg/usr/share/applications
		for desktop in *.desktop; do
			. $desktop 2>/dev/null
			if [[ "$Icon" ]]; then
				if [ ! "$Icon" == "${Icon%.*}" ]; then
					sed '/Icon/s/\..*$//' -i $desktop
					. $desktop 2>/dev/null
				fi
				if [ -d "$startdir/pkg/usr/share/pixmaps" ]; then
					cd $startdir/pkg/usr/share/pixmaps
					for pixmaps in *; do
						[ -d $pixmaps ] && continue
						[ ! "${pixmaps##*.}" == "png" ] && continue
				 		if [ "${pixmaps%.*}" == "$Icon" ]; then
				 			DIR=$(file $pixmaps | awk -F, '{print $2}' | sed 's/ //g')
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $pixmaps $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							if [[ ! "$(ls $startdir/pkg/usr/share/pixmaps)" ]]; then
								rm -rf $startdir/pkg/usr/share/pixmaps
							fi
						fi
					done
				fi
				if [ -d "$startdir/pkg/usr/share/icons" ]; then
					cd $startdir/pkg/usr/share/icons
					for icons in *; do
				 		if [ "${icons%.*}" == "$Icon" ]; then
							[ ! "${icons##*.}" == "png" ] && continue
				 			DIR=$(file $icons | awk -F, '{print $2}' | sed 's/ //g')
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $icons $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
						fi
					done
				fi
			fi
		done
	fi
}

strip_binaries() {
	cd $startdir/pkg
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
}

gzip_man_and_info_pages() {
	for DOCS in man info; do
		if [ -d "$startdir/pkg/usr/share/$DOCS" ]; then
			mv $startdir/pkg/usr/share/$DOCS $startdir/pkg/usr/$DOCS
			if [[ ! "$(ls $startdir/pkg/usr/share)" ]]; then
				rm -rf $startdir/pkg/usr/share
			fi
		fi
		if [ -d "$startdir/pkg/usr/$DOCS" ]; then
			# I've never seen symlinks in info pages....
			if [ "$DOCS" == "man" ]; then
				(cd $startdir/pkg/usr/$DOCS
				for manpagedir in $(find . -type d -name "man*" 2> /dev/null) ; do
					( cd $manpagedir
					for eachpage in $( find . -type l -maxdepth 1 2> /dev/null) ; do
						ln -s $( readlink $eachpage ).gz $eachpage.gz
						rm $eachpage
					done )
				done)
			fi
			find $startdir/pkg/usr/$DOCS -type f -exec gzip -9 '{}' \;
		fi
	done
}

set_post_permissions() {
	for DIRS in usr/bin usr/share/icons usr/doc; do
		if [ -d "$startdir/pkg/$DIRS" ]; then
			chown -R root:root $startdir/pkg/$DIRS
		fi
	done
}

copy_build_script() {
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver/
	cp $startdir/build-$pkgname.sh $startdir/pkg/usr/src/$pkgname-$pkgver/build-$pkgname.sh
	[ -f $startdir/ZENBUILD ] && cp $startdir/ZENBUILD $startdir/pkg/usr/src/$pkgname-$pkgver/ZENBUILD
}

create_package() {
	cd $startdir/pkg
	/sbin/makepkg -l y -c n $startdir/$package.tgz
	cd $startdir
	md5sum $package.tgz > $startdir/$package.md5
}

#########End Redundant Code#####################################
#########Begin Non Redundant Code##############################

prepare_directory() {
	mkdir $startdir/src
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
		if [ ! -f "$(basename $SOURCES)" ]; then
			if [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
				echo -e "\nDownloading $(basename $SOURCES)\n"
				wget $SOURCES
				if [ ! "$?" == "0" ]; then
					echo "Download failed"
					exit 2
				fi 
			else
				echo "$SOURCES does not appear to be a url nor is it in the directory"
				exit 2
			fi
		fi
		cp -R $(basename $SOURCES) $startdir/src
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			cp -R $startdir/$(basename $SOURCES) $startdir/pkg/usr/src/$pkgname-$pkgver/
		fi
		if [ "${SOURCES##*.}" == "desktop" ]; then
			mkdir -p $startdir/pkg/usr/share/applications
			cp -R $startdir/$(basename $SOURCES) $startdir/pkg/usr/share/applications
		fi
	done
}

extract_source() {
	cd $startdir/src
	if [[ "$(ls $startdir/src)" ]]; then	
		for FILES in ${source[@]}; do
			FILES="$(basename $FILES)"
			if [ "$(echo $FILES | grep tar)" -o "$(echo $FILES | grep tgz)" ]; then
				tar xf $FILES
			fi
			if [[ "$(echo $FILES | grep zip)" ]]; then
				unzip $FILES
			fi
		done
	elif [ ! "$source" ]; then
		echo -n "" # lame fix
	else
		echo "no files in the src directory $startdir/src"
		exit 2
	fi
}

build() {
	export PATH=/usr/lib/qt4/bin:$PATH
	export LD_LIBRARY_PATH=/usr/lib/qt4/lib:$LD_LIBRARY_PATH
	export DYLD_LIBRARY_PATH=/usr/lib/qt4/lib:$DYLD_LIBRARY_PATH
	cd $startdir/src/$pkgname-$pkgver
	qmake -unix PREFIX=/usr pstplus.pro
	sed -i 's|CFLAGS        =|CFLAGS       +=|' \
		Makefile
	sed -i 's|CXXFLAGS      =|CXXFLAGS     +=|' \
		Makefile
	make || return 1
	make install INSTALL_ROOT=$startdir/pkg
	
	# docs
	rm $startdir/pkg/usr/share/$pkgname/AUTHORS
	rm $startdir/pkg/usr/share/$pkgname/COPYING
	
	# icons
	mkdir -p $startdir/pkg/usr/share/icons/hicolor/16x16/apps
	mkdir -p $startdir/pkg/usr/share/icons/hicolor/22x22/apps
	mkdir -p $startdir/pkg/usr/share/icons/hicolor/32x32/apps
	mkdir -p $startdir/pkg/usr/share/icons/hicolor/48x48/apps
	mkdir -p $startdir/pkg/usr/share/icons/hicolor/64x64/apps
	mkdir -p $startdir/pkg/usr/share/icons/hicolor/128x128/apps
	mkdir -p $startdir/pkg/usr/share/icons/hicolor/scalable/apps
	mv $startdir/pkg/usr/share/$pkgname/${pkgname}16x16.png $startdir/pkg/usr/share/icons/hicolor/16x16/apps/$pkgname.png
	mv $startdir/pkg/usr/share/$pkgname/${pkgname}22x22.png $startdir/pkg/usr/share/icons/hicolor/22x22/apps/$pkgname.png
	mv $startdir/pkg/usr/share/$pkgname/${pkgname}32x32.png $startdir/pkg/usr/share/icons/hicolor/32x32/apps/$pkgname.png
	mv $startdir/pkg/usr/share/$pkgname/${pkgname}48x48.png $startdir/pkg/usr/share/icons/hicolor/48x48/apps/$pkgname.png
	mv $startdir/pkg/usr/share/$pkgname/${pkgname}64x64.png $startdir/pkg/usr/share/icons/hicolor/64x64/apps/$pkgname.png
	mv $startdir/pkg/usr/share/$pkgname/${pkgname}128x128.png $startdir/pkg/usr/share/icons/hicolor/128x128/apps/$pkgname.png
	mv $startdir/pkg/usr/share/$pkgname/$pkgname.svg $startdir/pkg/usr/share/icons/hicolor/scalable/apps/$pkgname.svg
	
	# .desktop file
	mkdir -p $startdir/pkg/usr/share/applications
	mv $startdir/pkg/usr/share/$pkgname/$pkgname.desktop $startdir/pkg/usr/share/applications
	sed -i 's|Categories=Application;Office;Publishing;X-SuSE-Core-Office;X-Mandriva-Office-Publishing;Qt;X-Misc;|Categories=Application;Office;|'\
		$startdir/pkg/usr/share/applications/$pkgname.desktop
}

create_slackdesc() {
mkdir $startdir/pkg/install
cat <<"EODESC" >$startdir/pkg/install/slack-desc
pstplus: pstplus (LaTeX/Pstricks assistant)
pstplus: 
pstplus: PST+ is an assistant program which facilitates the creation of
pstplus: LaTeX/PsTricks figures. Currently the graphical user interface of the
pstplus: program is available in french only.
pstplus: 
pstplus: 
pstplus: 
pstplus: 
pstplus: 
pstplus: 
EODESC
}

copy_docs() {
	for stuff in ${docs[@]}; do
		if [ ! -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
			mkdir -p $startdir/pkg/usr/doc/$pkgname-$pkgver
		fi
		find $startdir/src -type f -iname "$stuff" -exec cp -R '{}' $startdir/pkg/usr/doc/$pkgname-$pkgver \;
	done
}
detect_dependencies() {
	echo "Detecting dependencies..."
	depends=$(requiredbuilder -z $startdir/$package.tgz)
	
	depstring=$depends,tetex
	unset FIRST
	for deps in $(echo "${depstring}" | sed 's/,/\n/g' | sort -u); do
		if [[ ! "$FIRST" ]]; then
			finaldeps=$deps,
			FIRST='1'
			continue
		fi
		finaldeps=${finaldeps}${deps},
	done
	echo "$finaldeps" | sed -e 's/^,//' -e 's/,$//' > $startdir/$package.dep
}

####End Non Redundant Code############################

#Variables

startdir=$(pwd)
SRC=$startdir/src
PKG=$startdir/pkg

pkgname=pstplus
pkgver=1.2
pkgrel=1
zenver=50
arch=i486
package=$pkgname-$pkgver-$arch-$zenver.$pkgrel
source=(http://www.xm1math.net/pstplus/pstplus-1.2.tar.bz2)
docs=(authors copying install)
export CFLAGS="-O2 -march=i486 -mtune=i686"
export CXXFLAGS="-O2 -march=i486 -mtune=i686"

#Execution

check_for_root
clean_old_builds
prepare_directory
extract_source
set_pre_permissions
build
if [ ! "$?" = "0" ]; then
	echo "build() failed."
	exit 2
fi
create_slackdesc
copy_docs
check_for_menu_complaince
strip_binaries
gzip_man_and_info_pages
set_post_permissions
copy_build_script
create_package
detect_dependencies
echo "Package has been built."
